BaudRate

Enum BaudRate 

pub enum BaudRate {
    Baud110,
    Baud300,
    Baud600,
    Baud1200,
    Baud2400,
    Baud4800,
    Baud9600,
    Baud19200,
    Baud38400,
    Baud57600,
    Baud115200,
    BaudOther(usize),
}
Serial port baud rates.

Portability

The BaudRate variants with numeric suffixes, e.g., Baud9600, indicate standard baud rates that are widely-supported on many systems. While non-standard baud rates can be set with BaudOther, their behavior is system-dependent. Some systems may not support arbitrary baud rates. Using the standard baud rates is more likely to result in portable applications.

Variants



Baud110

110 baud.



Baud300

300 baud.



Baud600

600 baud.



Baud1200

1200 baud.



Baud2400

2400 baud.



Baud4800

4800 baud.



Baud9600

9600 baud.



Baud19200

19,200 baud.



Baud38400

38,400 baud.



Baud57600

57,600 baud.



Baud115200

115,200 baud.



BaudOther(usize)

Non-standard baud rates.

BaudOther can be used to set non-standard baud rates by setting its member to be the desired baud rate.

serial_core::BaudOther(4_000_000); // 4,000,000 baud

Non-standard baud rates may not be supported on all systems.

Implementations

Source

impl BaudRate

pub fn from_speed(speed: usize) -> BaudRate

Creates a BaudRate for a particular speed.

This function can be used to select a BaudRate variant from an integer containing the desired baud rate.

Example
assert_eq!(BaudRate::Baud9600, BaudRate::from_speed(9600));
assert_eq!(BaudRate::Baud115200, BaudRate::from_speed(115200));
assert_eq!(BaudRate::BaudOther(4000000), BaudRate::from_speed(4000000));
pub fn speed(&self) -> usize

Returns the baud rate as an integer.

Example
assert_eq!(9600, BaudRate::Baud9600.speed());
assert_eq!(115200, BaudRate::Baud115200.speed());
assert_eq!(4000000, BaudRate::BaudOther(4000000).speed());